==> church_of_jesus_christ_api-0.2.3.tar.gz: church_of_jesus_christ_api-0.2.3/doc/source/JSON_schemas/get_member_service-schema.md <==
{
  authorizedToAddEndowment: bool,
  authorizedToEditMelchizedekPriesthood: bool,
  authorizedToPrintCertificates: bool,
  authorizedToPrintMelchizedekPriesthood: bool,
  authorizedToUpdateContactInfo: bool,
  authorizedToUpdateRecord: bool,
  authorizedToViewAnnotations: bool,
  authorizedToViewHTVT: bool,
  authorizedToViewRecord: bool,
  authorizedToViewReportBasic: bool,
  canChangeMoveRestriction: bool,
  consentFormId: NoneType,
  consentFormMediaType: NoneType,
  family: {
    children: list,
    hohMrn: NoneType,
    marriage: {
      authorizedToViewNonMemberSpouse: bool,
      country: NoneType,
      countryId: NoneType,
      date: NoneType,
      errors: {},
      individualId: int,
      legalNameGroup: NoneType,
      madeHeadOfHousehold: bool,
      marriageId: str,
      marriageTerminated: bool,
      marriageTerminationCause: NoneType,
      memberStatus: NoneType,
      memberType: NoneType,
      mrn: str,
      nonMemberSpouseNameBirthdateNotEditable: bool,
      place: NoneType,
      preferredNameGroup: NoneType,
      restorationOfBlessingsRequired: bool,
      sealedToPriorSpouse: bool,
      sealingDate: NoneType,
      sealingTemple: NoneType,
      showTempleInfo: bool,
      spouse: {
        age: int,
        allPriesthoodOrdinations: NoneType,
        birthDate: str,
        deathDate: NoneType,
        deceased: bool,
        displayBirthDate: str,
        gender: str,
        headOfHousehold: bool,
        id: int,
        inAuthorizedUnit: bool,
        inHousehold: bool,
        linkedRecord: bool,
        listName: str,
        maidenName: str,
        maidenOrLegalName: str,
        member: bool,
        mrn: NoneType,
        name: str,
        nameGroup: NoneType,
        noMrnInitiated: bool,
        pendingId: NoneType,
        preferredOrLegalName: str,
        priesthood: NoneType,
        priesthoodCode: NoneType,
        priesthoodType: NoneType,
        relationship: str,
        relationshipDisplay: str,
        spokenName: NoneType,
        unitNumber: int,
        unknown: bool
      },
      spouseDeceased: bool,
      spouseEditable: bool,
      spouseId: int,
      spouseInDifferentWardBranch: bool,
      spouseMember: bool,
      spouseMrn: NoneType,
      spouseUnitNumber: int,
      templeId: NoneType,
      terminationDate: NoneType,
      updateName: NoneType,
      updateRequests: NoneType,
      warnings: {}
    },
    parents: NoneType
  },
  household: {
    errors: {},
    familyNameGroup: {
      autoRomanize: bool,
      formattedLatin: str,
      formattedLocal: str,
      name1: {
        family: str,
        given: NoneType,
        label: str,
        labelKey: NoneType,
        suffix: NoneType,
        translitSource: bool,
        writingSystem: str
      },
      name2: NoneType,
      name3: NoneType
    },
    hohMrn: NoneType,
    members: [
      {
        age: int,
        allPriesthoodOrdinations: NoneType,
        birthDate: str,
        deathDate: NoneType,
        deceased: bool,
        displayBirthDate: str,
        gender: str,
        headOfHousehold: bool,
        id: int,
        inAuthorizedUnit: bool,
        inHousehold: bool,
        linkedRecord: bool,
        listName: str,
        maidenName: NoneType,
        maidenOrLegalName: str,
        member: bool,
        mrn: NoneType,
        name: str,
        nameGroup: NoneType,
        noMrnInitiated: bool,
        pendingId: NoneType,
        preferredOrLegalName: str,
        priesthood: NoneType,
        priesthoodCode: NoneType,
        priesthoodType: NoneType,
        relationship: str,
        relationshipDisplay: str,
        spokenName: NoneType,
        unitNumber: int,
        unknown: bool
      }
    ]
  },
  individual: {
    actualAge: int,
    actualAgeInMonths: int,
    adultAgeOrMarried: bool,
    age: int,
    ageAsOfDec31: int,
    ageAsOfDec31NextYear: NoneType,
    birthCountry: NoneType,
    birthCountryId: NoneType,
    birthDate: str,
    birthDateDisplay: str,
    birthPlace: NoneType,
    canHaveCalling: bool,
    canHaveHTAssignment: bool,
    canHaveMaidenName: bool,
    canHaveVTAssignment: bool,
    confidentialEvents: NoneType,
    email: str,
    endowed: bool,
    errors: {},
    formattedHouseholdCoupleName: str,
    formattedMrn: NoneType,
    gender: str,
    hasOutOfUnitRecord: bool,
    hasPatriarchalBlessing: bool,
    head: bool,
    headInUnit: bool,
    hohId: int,
    hohName: str,
    householdEmail: NoneType,
    householdPhone: NoneType,
    hqMoveRestriction: bool,
    id: int,
    legalNameGroup: {
      autoRomanize: bool,
      formattedLatin: str,
      formattedLocal: str,
      name1: {
        family: str,
        given: str,
        label: str,
        labelKey: NoneType,
        suffix: NoneType,
        translitSource: bool,
        writingSystem: str
      },
      name2: NoneType,
      name3: NoneType
    },
    maidenNameGroup: {
      autoRomanize: bool,
      formattedLatin: NoneType,
      formattedLocal: NoneType,
      name1: {
        family: NoneType,
        given: NoneType,
        label: str,
        labelKey: NoneType,
        suffix: NoneType,
        translitSource: bool,
        writingSystem: str
      },
      name2: NoneType,
      name3: NoneType
    },
    mailingAddress: {
      city: NoneType,
      country: NoneType,
      district: NoneType,
      formattedLines: NoneType,
      geocodeToUnits: bool,
      postalCode: NoneType,
      standardized: NoneType,
      state: NoneType,
      street1: NoneType,
      street2: NoneType,
      units: NoneType
    },
    mailingSameAsResidential: bool,
    missionCountry: NoneType,
    missionCountryId: NoneType,
    missionLanguage: NoneType,
    missionLanguageId: NoneType,
    moveDate: NoneType,
    moveDateDuration: NoneType,
    moveRestriction: bool,
    moveRestrictionDate: NoneType,
    mrn: NoneType,
    name: str,
    nameUpdateReason: NoneType,
    notAccountable: bool,
    outOfUnit: bool,
    phone: str,
    preferredNameGroup: {
      autoRomanize: bool,
      formattedLatin: str,
      formattedLocal: str,
      name1: {
        family: str,
        given: str,
        label: str,
        labelKey: NoneType,
        suffix: NoneType,
        translitSource: bool,
        writingSystem: str
      },
      name2: NoneType,
      name3: NoneType
    },
    priesthood: str,
    priesthoodCode: int,
    primaryUnitName: str,
    primaryUnitNumber: NoneType,
    priorUnitName: NoneType,
    priorUnitNumber: NoneType,
    priorUnits: NoneType,
    recommendStatus: NoneType,
    residentialAddress: {
      city: str,
      country: int,
      district: NoneType,
      formattedLines: [
        str
      ],
      geocodeToUnits: bool,
      postalCode: str,
      standardized: NoneType,
      state: int,
      street1: str,
      street2: NoneType,
      units: NoneType
    },
    restorationOfBlessingsRequired: bool,
    sealedToSpouse: bool,
    spouseId: int,
    spouseInUnit: bool,
    spouseName: str,
    templeRecStatuses: NoneType,
    unitName: str,
    unitNumber: str,
    unsubscribedFromEmail: bool,
    updateRequests: NoneType,
    warnings: {}
  },
  individualName: str,
  membershipUpdateRequests: NoneType,
  ordinances: {
    allOrdinances: [
      {
        bic: bool,
        date: NoneType,
        note: NoneType,
        occurred: bool,
        ordinanceName: str,
        ordinanceType: str,
        templeId: NoneType,
        updateRequestExists: bool
      }
    ],
    baptism: {
      bic: bool,
      date: NoneType,
      note: NoneType,
      occurred: bool,
      ordinanceName: str,
      ordinanceType: str,
      templeId: NoneType,
      updateRequestExists: bool
    },
    bic: {
      bic: bool,
      date: NoneType,
      note: NoneType,
      occurred: bool,
      ordinanceName: str,
      ordinanceType: str,
      templeId: NoneType,
      updateRequestExists: bool
    },
    confirmation: {
      bic: bool,
      date: NoneType,
      note: NoneType,
      occurred: bool,
      ordinanceName: str,
      ordinanceType: str,
      templeId: NoneType,
      updateRequestExists: bool
    },
    endowment: {
      bic: bool,
      date: NoneType,
      note: NoneType,
      occurred: bool,
      ordinanceName: str,
      ordinanceType: str,
      templeId: NoneType,
      updateRequestExists: bool
    },
    errors: {},
    hasEditableFields: bool,
    ordinanceFields: [
      str
    ],
    priesthoods: {
      apostle: NoneType,
      deacon: NoneType,
      elder: {
        aaronic: bool,
        bic: bool,
        date: NoneType,
        melchizedek: bool,
        note: NoneType,
        occurred: bool,
        ordinanceName: str,
        ordinanceType: str,
        priesthoodType: NoneType,
        templeId: NoneType,
        updateRequestExists: bool
      },
      highPriest: NoneType,
      priest: NoneType,
      priesthoods: [
        {
          aaronic: bool,
          bic: bool,
          date: NoneType,
          melchizedek: bool,
          note: NoneType,
          occurred: bool,
          ordinanceName: str,
          ordinanceType: str,
          priesthoodType: NoneType,
          templeId: NoneType,
          updateRequestExists: bool
        }
      ],
      seventy: NoneType,
      teacher: NoneType,
      unknown: NoneType
    },
    restorationOfBlessings: bool,
    sealedToParents: NoneType,
    sealedToSpouse: {
      bic: bool,
      date: NoneType,
      note: NoneType,
      occurred: bool,
      ordinanceName: str,
      ordinanceType: str,
      templeId: NoneType,
      updateRequestExists: bool
    },
    updateRequests: NoneType,
    warnings: {}
  },
  outOfUnitMember: bool,
  recommend: NoneType,
  showNotEditEnabledMessage: bool,
  stakeOrDistrictUser: bool,
  unitLocaleData: {
    addressFields: [
      str
    ],
    hasLatinWritingSystem: bool,
    name1WritingSystem: str,
    name2WritingSystem: NoneType
  },
  withinStewardship: bool
}

==> church_of_jesus_christ_api-0.2.8.tar.gz: church_of_jesus_christ_api-0.2.8/doc/source/JSON_schemas/get_member_service-schema.md <==
{
  authorizedToAddEndowment: bool,
  authorizedToEditMelchizedekPriesthood: bool,
  authorizedToPrintCertificates: bool,
  authorizedToPrintMelchizedekPriesthood: bool,
  authorizedToUpdateContactInfo: bool,
  authorizedToUpdateRecord: bool,
  authorizedToViewAnnotations: bool,
  authorizedToViewHTVT: bool,
  authorizedToViewRecord: bool,
  authorizedToViewReportBasic: bool,
  canChangeMoveRestriction: bool,
  consentFormId: NoneType,
  consentFormMediaType: NoneType,
  family: {
    children: list,
    hohMrn: str,
    marriage: {
      authorizedToViewNonMemberSpouse: bool,
      country: NoneType,
      countryId: NoneType,
      date: NoneType,
      errors: {},
      individualId: int,
      legalNameGroup: NoneType,
      madeHeadOfHousehold: bool,
      marriageId: str,
      marriageTerminated: bool,
      marriageTerminationCause: NoneType,
      memberStatus: NoneType,
      memberType: NoneType,
      mrn: str,
      nonMemberSpouseNameBirthdateNotEditable: bool,
      place: NoneType,
      preferredNameGroup: NoneType,
      restorationOfBlessingsRequired: bool,
      sealedToPriorSpouse: bool,
      sealingDate: NoneType,
      sealingTemple: NoneType,
      showTempleInfo: bool,
      spouse: {
        age: int,
        allPriesthoodOrdinations: NoneType,
        birthDate: str,
        deathDate: NoneType,
        deceased: bool,
        displayBirthDate: str,
        gender: str,
        headOfHousehold: bool,
        id: int,
        inAuthorizedUnit: bool,
        inHousehold: bool,
        linkedRecord: bool,
        listName: str,
        maidenName: str,
        maidenOrLegalName: str,
        member: bool,
        mrn: str,
        name: str,
        nameGroup: NoneType,
        noMrnInitiated: bool,
        pendingId: NoneType,
        preferredOrLegalName: str,
        priesthood: NoneType,
        priesthoodCode: NoneType,
        priesthoodType: NoneType,
        relationship: str,
        relationshipDisplay: str,
        spokenName: NoneType,
        unitNumber: int,
        unknown: bool
      },
      spouseDeceased: bool,
      spouseEditable: bool,
      spouseId: int,
      spouseInDifferentWardBranch: bool,
      spouseMember: bool,
      spouseMrn: NoneType,
      spouseUnitNumber: int,
      templeId: NoneType,
      terminationDate: NoneType,
      updateName: NoneType,
      updateRequests: NoneType,
      warnings: {}
    },
    parents: NoneType
  },
  household: {
    errors: {},
    familyNameGroup: {
      autoRomanize: bool,
      formattedLatin: str,
      formattedLocal: str,
      name1: {
        family: str,
        given: NoneType,
        label: str,
        labelKey: NoneType,
        suffix: NoneType,
        translitSource: bool,
        writingSystem: str
      },
      name2: NoneType,
      name3: NoneType
    },
    hohMrn: str,
    members: [
      {
        age: int,
        allPriesthoodOrdinations: NoneType,
        birthDate: str,
        deathDate: NoneType,
        deceased: bool,
        displayBirthDate: str,
        gender: str,
        headOfHousehold: bool,
        id: int,
        inAuthorizedUnit: bool,
        inHousehold: bool,
        linkedRecord: bool,
        listName: str,
        maidenName: NoneType,
        maidenOrLegalName: str,
        member: bool,
        mrn: str,
        name: str,
        nameGroup: NoneType,
        noMrnInitiated: bool,
        pendingId: NoneType,
        preferredOrLegalName: str,
        priesthood: NoneType,
        priesthoodCode: NoneType,
        priesthoodType: NoneType,
        relationship: str,
        relationshipDisplay: str,
        spokenName: NoneType,
        unitNumber: int,
        unknown: bool
      }
    ]
  },
  individual: {
    actualAge: int,
    actualAgeInMonths: int,
    adultAgeOrMarried: bool,
    age: int,
    ageAsOfDec31: int,
    ageAsOfDec31NextYear: NoneType,
    birthCountry: str,
    birthCountryId: int,
    birthDate: str,
    birthDateDisplay: str,
    birthPlace: str,
    canHaveCalling: bool,
    canHaveHTAssignment: bool,
    canHaveMaidenName: bool,
    canHaveVTAssignment: bool,
    confidentialEvents: NoneType,
    email: str,
    endowed: bool,
    errors: {},
    formattedHouseholdCoupleName: str,
    formattedMrn: str,
    gender: str,
    hasOutOfUnitRecord: bool,
    hasPatriarchalBlessing: bool,
    head: bool,
    headInUnit: bool,
    hohId: int,
    hohName: str,
    householdEmail: str,
    householdPhone: str,
    hqMoveRestriction: bool,
    id: int,
    legalNameGroup: {
      autoRomanize: bool,
      formattedLatin: str,
      formattedLocal: str,
      name1: {
        family: str,
        given: str,
        label: str,
        labelKey: NoneType,
        suffix: NoneType,
        translitSource: bool,
        writingSystem: str
      },
      name2: NoneType,
      name3: NoneType
    },
    maidenNameGroup: {
      autoRomanize: bool,
      formattedLatin: NoneType,
      formattedLocal: NoneType,
      name1: {
        family: NoneType,
        given: NoneType,
        label: str,
        labelKey: NoneType,
        suffix: NoneType,
        translitSource: bool,
        writingSystem: str
      },
      name2: NoneType,
      name3: NoneType
    },
    mailingAddress: {
      city: NoneType,
      country: NoneType,
      district: NoneType,
      formattedLines: NoneType,
      geocodeToUnits: bool,
      membershipUpdateRequestAccepted: bool,
      postalCode: NoneType,
      standardized: NoneType,
      state: NoneType,
      street1: NoneType,
      street2: NoneType,
      units: NoneType
    },
    mailingSameAsResidential: bool,
    missionCountry: str,
    missionCountryId: int,
    missionLanguage: str,
    missionLanguageId: int,
    moveDate: str,
    moveDateDuration: str,
    moveRestriction: bool,
    moveRestrictionDate: NoneType,
    mrn: str,
    name: str,
    nameUpdateReason: NoneType,
    notAccountable: bool,
    outOfUnit: bool,
    phone: str,
    preferredNameGroup: {
      autoRomanize: bool,
      formattedLatin: str,
      formattedLocal: str,
      name1: {
        family: str,
        given: str,
        label: str,
        labelKey: NoneType,
        suffix: NoneType,
        translitSource: bool,
        writingSystem: str
      },
      name2: NoneType,
      name3: NoneType
    },
    priesthood: str,
    priesthoodCode: int,
    primaryUnitName: str,
    primaryUnitNumber: NoneType,
    priorUnitName: str,
    priorUnitNumber: str,
    priorUnits: [
      {
        au: bool,
        durationText: NoneType,
        parentUnitName: NoneType,
        parentUnitNumber: NoneType,
        unitName: str,
        unitNumber: str
      }
    ],
    recommendStatus: str,
    residentialAddress: {
      city: str,
      country: int,
      district: NoneType,
      formattedLines: [
        str
      ],
      geocodeToUnits: bool,
      membershipUpdateRequestAccepted: bool,
      postalCode: str,
      standardized: NoneType,
      state: int,
      street1: str,
      street2: NoneType,
      units: NoneType
    },
    restorationOfBlessingsRequired: bool,
    sealedToSpouse: bool,
    spouseId: int,
    spouseInUnit: bool,
    spouseName: str,
    templeRecStatuses: [
      str
    ],
    unitName: str,
    unitNumber: str,
    unsubscribedFromEmail: bool,
    updateRequests: NoneType,
    warnings: {}
  },
  individualName: str,
  membershipUpdateRequests: NoneType,
  ordinances: {
    allOrdinances: [
      {
        bic: bool,
        date: NoneType,
        note: NoneType,
        occurred: bool,
        ordinanceName: str,
        ordinanceType: str,
        templeId: NoneType,
        updateRequestExists: bool
      }
    ],
    baptism: {
      bic: bool,
      date: NoneType,
      note: NoneType,
      occurred: bool,
      ordinanceName: str,
      ordinanceType: str,
      templeId: NoneType,
      updateRequestExists: bool
    },
    bic: {
      bic: bool,
      date: NoneType,
      note: NoneType,
      occurred: bool,
      ordinanceName: str,
      ordinanceType: str,
      templeId: NoneType,
      updateRequestExists: bool
    },
    confirmation: {
      bic: bool,
      date: NoneType,
      note: NoneType,
      occurred: bool,
      ordinanceName: str,
      ordinanceType: str,
      templeId: NoneType,
      updateRequestExists: bool
    },
    endowment: {
      bic: bool,
      date: NoneType,
      note: NoneType,
      occurred: bool,
      ordinanceName: str,
      ordinanceType: str,
      templeId: NoneType,
      updateRequestExists: bool
    },
    errors: {},
    hasEditableFields: bool,
    ordinanceFields: [
      str
    ],
    priesthoods: {
      apostle: NoneType,
      deacon: NoneType,
      elder: {
        aaronic: bool,
        bic: bool,
        date: NoneType,
        melchizedek: bool,
        note: NoneType,
        occurred: bool,
        ordinanceName: str,
        ordinanceType: str,
        priesthoodType: str,
        templeId: NoneType,
        updateRequestExists: bool
      },
      highPriest: NoneType,
      priest: NoneType,
      priesthoods: [
        {
          aaronic: bool,
          bic: bool,
          date: NoneType,
          melchizedek: bool,
          note: NoneType,
          occurred: bool,
          ordinanceName: str,
          ordinanceType: str,
          priesthoodType: str,
          templeId: NoneType,
          updateRequestExists: bool
        }
      ],
      seventy: NoneType,
      teacher: NoneType,
      unknown: NoneType
    },
    restorationOfBlessings: bool,
    sealedToParents: NoneType,
    sealedToSpouse: {
      bic: bool,
      date: NoneType,
      note: NoneType,
      occurred: bool,
      ordinanceName: str,
      ordinanceType: str,
      templeId: NoneType,
      updateRequestExists: bool
    },
    updateRequests: NoneType,
    warnings: {}
  },
  outOfUnitMember: bool,
  recommend: {
    editable: bool,
    expirationDate: str,
    formattedMrn: str,
    gender: str,
    individualId: int,
    issueMonth: str,
    issueYear: str,
    issueable: bool,
    issuingParentUnitName: NoneType,
    issuingUnitName: NoneType,
    limitedUse: bool,
    limitedUseValidThrough: NoneType,
    name: str,
    number: str,
    parentUnitName: str,
    recommendNumber: NoneType,
    status: str,
    unitName: str
  },
  showNotEditEnabledMessage: bool,
  stakeOrDistrictUser: bool,
  unitLocaleData: {
    addressFields: [
      str
    ],
    hasLatinWritingSystem: bool,
    name1WritingSystem: str,
    name2WritingSystem: NoneType
  },
  withinStewardship: bool
}
